<h1 align="center">Furomon</h1>
<a href="https://pradyunsg.me/furo/">
  <img align="center" src="https://github.com/scalabli/furomon/raw/main/docs/_static/demo.png" alt="Demo image">
</a>



`Forever Scalable`

**Furomon** is a clean customisable Sphinx documentation theme based on Furo by Pradyun Gedam.

Furomon, the mount Furo, a Chakma word which means the mountain which pierced through Earth. It teaches us to be firm and determined against all odds.

## Features


- **Intentionally minimal** --- the most important thing is the content, not the scaffolding around it.
- **Responsive** --- adapting perfectly to the available screen space, to work on all sorts of devices.
- **Customisable** --- change the color palette, font families, logo and more!
- **Easy to navigate** --- with carefully-designed sidebar navigation and inter-page links.
- **Good looking content** --- through clear typography and well-stylised elements.
- **Good looking search** --- helps readers find what they want quickly.
- **Biased for smaller docsets** --- intended for smaller documentation sets, where presenting the entire hierarchy in the sidebar is not overwhelming.


## Quickstart


Furomon is distributed on [PyPI]. To use the theme in your Sphinx project:

1. Install Furomon in documentation's build environment.

   ```text
   pip install furomon
   ```

2. Update the `html_theme` in `conf.py`.

   ```py
   html_theme = "furomon"
   ```

3. Your Sphinx documentation's HTML pages will now be generated with this theme! 🎉

[pypi]: https://pypi.org/project/furomon/




## Donate🎁

In order to for us to maintain this project and grow our community of contributors.
[Donate](https://ko-fi.com/scalabli)



## Getting Help

### Community

For discussions about the usage, development, and the future of quo, please join our Google community

* [Community👨‍👩‍👦‍👦](https://groups.google.com/g/scalabli)

## Resources

### Bug tracker

If you have any suggestions, bug reports, or annoyances please report them
to our issue tracker at 
[Bug tracker](https://github.com/scalabli/furomon/issues/) or send an email to:

 📥 scalabli@googlegroups.com | scalabli@proton.me
 
 
## License📑

[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)  
This software is licensed under the `MIT License`. See the [License](https://github.com/scalabli/furomon/blob/master/LICENSE) file in the top distribution directory for the full license text.


## Code of Conduct
Code of Conduct is adapted from the Contributor Covenant,
version 1.2.0 available at
[Code of Conduct](http://contributor-covenant.org/version/1/2/0/)


